# Prod 20231024_v0.10.4_base_dec_min_2924_min_1802_6166


Base prod for missing declination in `20230901_v0.10.4_base_prod`

```
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20231024_v0.10.4_base_dec_min_2924_min_1802_6166 --dec_list dec_min_2924 dec_min_1802 dec_6166
```

contact: Thomas Vuillaume

